@@ -5,9 +5,13 @@ package main
 //go:generate git tag -af v$VERSION -m "v$VERSION"
 
 import (
-	"log"
+	"fmt"
+	"os"
+	"os/signal"
+	"syscall"
 
 	"github.com/schollz/croc/v10/src/cli"
+	"github.com/schollz/croc/v10/src/utils"
 )
 
 func main() {
@@ -27,7 +31,25 @@ func main() {
 	// 		fmt.Println("wrote profile")
 	// 	}
 	// }()
-	if err := cli.Run(); err != nil {
-		log.Fatalln(err)
-	}
+
+	// Create a channel to receive OS signals
+	sigs := make(chan os.Signal, 1)
+	signal.Notify(sigs, syscall.SIGINT, syscall.SIGTERM)
+
+	go func() {
+		if err := cli.Run(); err != nil {
+			fmt.Println(err)
+			os.Exit(1)
+		}
+		// Exit the program gracefully
+		utils.RemoveMarkedFiles()
+		os.Exit(0)
+	}()
+
+	// Wait for a termination signal
+	_ = <-sigs
+	utils.RemoveMarkedFiles()
+
+	// Exit the program gracefully
+	os.Exit(0)
 }
